@@ -29,6 +29,8 @@
 
 #include "Exception.hxx"
 
+#include <utility>
+
 template<typename T>
 static void
 AppendNestedMessage(std::string &result, T &&e,
@@ -42,6 +44,9 @@ AppendNestedMessage(std::string &result, T &&e,
 		AppendNestedMessage(result, nested, fallback, separator);
 	} catch (const std::nested_exception &ne) {
 		AppendNestedMessage(result, ne, fallback, separator);
+	} catch (const char *s) {
+		result += separator;
+		result += s;
 	} catch (...) {
 		result += separator;
 		result += fallback;
@@ -62,11 +67,13 @@ GetFullMessage(std::exception_ptr ep,
 	       const char *fallback, const char *separator) noexcept
 {
 	try {
-		std::rethrow_exception(ep);
+		std::rethrow_exception(std::move(ep));
 	} catch (const std::exception &e) {
 		return GetFullMessage(e, fallback, separator);
 	} catch (const std::nested_exception &ne) {
 		return GetFullMessage(ne.nested_ptr(), fallback, separator);
+	} catch (const char *s) {
+		return s;
 	} catch (...) {
 		return fallback;
 	}
